@@ -8,10 +8,9 @@ from twine.settings import Settings as twine_Settings
 from twine.commands.upload import upload as twine_upload
 
 join = os.path.join
-bat_name = 'uploadtool_build_source.bat'
 
-def Command(info, cmd, params=''):
-	ctypes.windll.shell32.ShellExecuteW(None, "runas", cmd, params, None, 0)
+class Const:
+	bat_name = 'uploadtool_build_source.bat'
 
 def UploadByTwine(info, timeout=20000):
 	"""直接调用twine的cmd貌似不起效果."""
@@ -90,15 +89,36 @@ class UploadTool(UploadInfo):
 		self.RemoveLast()
 		self.CopyFrom()
 		print("Finish Source Update.")
-	def BuildSetup(self):
+		
+	def BuildAndUpload(self):
+		"""
+		调用setup、twine，生成.tar.gz和.whl文件
+		"""
+		tmp_file_path = self.__build_temp_files()
+		os.system(tmp_file_path)
+		UploadByTwine(self)
+		self.__clean_temp_files(tmp_file_path)
+		
+	def __build_temp_files(self):
 		setup_path = join(self.path, 'setup.py')
-		bat_path = join(self.path, bat_name)
+		bat_path = join(self.path, Const.bat_name)
+		
+		# 注入bat
 		f = open(bat_path, 'w')
 		f.write("python {} bdist_wheel\n".format(setup_path))
 		f.write("python {} sdist".format(setup_path))
 		f.close()
-		Command(self, bat_path)
-		UploadByTwine(self)
+		
+		return bat_path
+	
+	def __clean_temp_files(self, bat_path):
+		
+		# 清除零时文件
+		try:
+			os.remove(bat_path)
+		except:
+			print("Failed to clean up bat<tmp>.")
+			
 	
 	def Upload(self):
 		"""
@@ -110,7 +130,8 @@ class UploadTool(UploadInfo):
 			raise Exception(err_str)
 		self.UpdateFiles()
 		self.RemoveDist()
-		self.BuildSetup()
+		self.BuildAndUpload()
+		
 	
 	def __call__(self):
 		self.Upload()
